# AIT Cyber Range Kyoushi - Simulation

The Kyoushi Simulation package provides a development API and cli utilities for creating
and running state machines. Developed state machines can be executed to automate the simulation
of both attacker and normal user behavior in a Cyber Range. Thus facilitating Cyber Range
exercises, IDS data set generation and other Cyber Range related tasks.
